#
# spec file for package libcint
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major 5
%define libname %{name}%{major}
%define develname   cint
Name:           libcint
Version:        5.5.0
Release:        1.2
Summary:        General Gaussian-type orbitals integrals for quantum chemistry
License:        BSD-2-Clause
URL:            https://github.com/sunqm/libcint
Source:         https://github.com/sunqm/libcint/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-fortran
BuildRequires:  openblas-devel
BuildRequires:  python3-numpy
# qcint is a drop-in replacement of the same library with architecture dependent optimizations
Conflicts:      qcint

%description
libcint is an open source library for analytical Gaussian integrals.
It provides C/Fortran API to evaluate one-electron / two-electron
integrals for Cartesian / real-spherical / spinor Gaussian type functions.

%package -n    %{libname}
Summary:        General Gaussian-type orbitals integrals for quantum chemistry

%description -n    %{libname}
libcint is an open source library for analytical Gaussian integrals.
It provides C/Fortran API to evaluate one-electron / two-electron
integrals for Cartesian / real-spherical / spinor Gaussian type functions.

%package -n     %{develname}-devel
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}
Conflicts:      qcint-devel

%description -n %{develname}-devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%cmake -DCMAKE_INSTALL_LIBDIR=%{_lib} \
       -DENABLE_EXAMPLE:BOOL=ON \
       -DWITH_F12:BOOL=ON \
       -DWITH_COULOMB_ERF:BOOL=ON \
       -DWITH_RANGE_COULOMB:BOOL=ON \
       -DENABLE_TEST:BOOL=ON \
       -DQUICK_TEST:BOOL=ON

%cmake_build

%install
%cmake_install

%check
%ctest

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/libcint.so.%{major}
%{_libdir}/libcint.so.%{version}

%files -n %{develname}-devel
%license LICENSE
%doc README.rst doc/program_ref.pdf
%{_includedir}/cint.h
%{_includedir}/cint_funcs.h
%{_libdir}/libcint.so

%changelog
* Wed Nov 15 2023 Dirk Müller <dmueller@suse.com>
- update to 5.5.0:
  * Fix memory leak issue in int4c1e
  * Add polynomial root finder with eigenvalue algorithm
  * Fitting Rys roots of SR integrals with Chebyshev polynomials
  * New integrals related to LRESC
  * Supports Gaussian model for int1e_grids
  * Add constant PTR_FRAC_CHARGE for QM/MM interface in pyscf
  * Improves rys-roots numerical stability in the near-zero limit
  * Improves rys-roots finder accuracy
  * Improve error handling for SR-ERI integrals
  * Optimize SR-ERI integral screening
  * Fix approx_log bug for non-x86 architecture
  * Fix integer overflow error in cintopt initialization
  * Boundary check when initializing CINTOpt
  * Add 4-center 1-electron intergral int4c1e
  * New integral int3c1e_ip1
  * New integral int1e_r4
  * Missing cart2sph function for l=15
  * Fix cint3c1e_cart integral
  * Fix integer overflow in gto_norm function
  * Update cint.h to make CINTEnvVars closed to the definition in
    qcint
  * Improve the cartesian-spinor transformation
  * Remove the dependency to BLAS library
  * Update the header file cint.h
  * Update the drivers for cint2e, cint3c2e, cint3c1e, cint2c2e
  * Fix uninitialized variables in rys_roots
  * Fix Cartesian-spherical and Cartesian-spinor transformation
    coefficients
  * Fix divide-by-0 bug
  * Improve performance of quadruple precision rys-roots function
  * Improve short-range rys-roots accuracy
- drop fix_control_reaches_end_of_non-void_function.patch
  (upstream)
* Thu Jun 17 2021 andy great <andythe_great@pm.me>
- Update to version 4.4.1.
  * Fix bugs in int1e_grids for attenuated Coulomb operators
- Updates for version 4.4.0.
  * Fix bugs in c2s transfomration for int1e_grids
  * Fix bugs int1e_grids code generator
  * Refactor cart2sph
  * Refactor int1e drivers
- Updates for version 4.3.0.
  * Add new integral type int1e_grids
  * Fix cache size type
- Updates for version 4.1.3.
  * Fix memory address int32 overflow for heavily contracted basis
- Updates for version 4.1.2 .
  * Fix a bug due to significant digits of float128 in the core Fmt integrals
- Updates for version 4.1.1.
  * Fix bug in short-range Coulomb core integrals
- Updates for version 4.1.0.
  * Add new Rys roots and weights algorithm
  * Improve integral accuracy for high angular momentum basis
  * Improve integral accuracy for short-range Coulomb integrals
  * Add supports of 2-e integrals up to l=15
- Add patch fix_control_reaches_end_of_non-void_function.patch
  Fix error control reaches end of non-void function in int3c2e.c
  Patch fixed upsteam.
* Tue Jan 12 2021 andy great <andythe_great@pm.me>
- Update to version 4.0.7.
  * Fix bug in rys_roots when R_dsmit fails to find all roots.
* Thu Nov 12 2020 andy great <andythe_great@pm.me>
- Update to version 4.0.6.
  * Fix return value bug in rysroots
- Update since 3.1.1.
  * Fix prescreening bug in int3c2e
  * Fix cache size bug in int3c1e
  * Fix memory allocation bug in int3c1e
  * Improve macro MALLOC_INSTACK
  * Fix function typedef bug in include/cint_funcs.h
  * Update cmake configs and docs
  * API Change. PTR_LIGHT_SPEED is replaced with PTR_EXPCUTOFF.
    Integral screening parameter can be passed through
    env[PTR_EXPCUTOFF]
  * Add short-range integrals for range-separation
  * Handle linear dependency in Rys polynomial
  * Avoid calling exit function
* Fri Sep  4 2020 andy great <andythe_great@pm.me>
- Clean up spec file.
* Thu Sep  3 2020 andy great <andythe_great@pm.me>
- Fix devel dependency.
* Tue Sep  1 2020 andy great <andythe_great@pm.me>
- Initial package release.
